Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(167)

Unified Diff: runtime/vm/flow_graph_type_propagator.cc

Issue 689713003: Context objects don't have a compile-type. Return dynamic-type in this case. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | tests/standalone/priority_queue_stress_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/flow_graph_type_propagator.cc
===================================================================
--- runtime/vm/flow_graph_type_propagator.cc (revision 41396)
+++ runtime/vm/flow_graph_type_propagator.cc (working copy)
@@ -548,9 +548,9 @@
if (type_ == NULL) {
ASSERT(cid_ != kIllegalCid);
- // VM internal Function objects don't have a compile-type. Return
- // dynamic-type in this case.
- if (cid_ == kFunctionCid) {
+ // VM internal Function and Context objects don't have a compile-type.
+ // Return dynamic-type in this case.
+ if (cid_ == kFunctionCid || cid_ == kContextCid) {
type_ = &Type::ZoneHandle(Type::DynamicType());
return type_;
}
« no previous file with comments | « no previous file | tests/standalone/priority_queue_stress_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698